@@ -18,7 +18,7 @@ class User(CentraEntity):
             is_saml_user: bool = False,
     ) -> CentraApiPayload:
     
-        params = {
+        data = {
             "action": "create",
             "username": username,
             "password": password,
@@ -32,7 +32,7 @@ class User(CentraEntity):
         }
 
         payload = CentraApiPayload(path=User._path, method="POST", return_type=User,
-                                   params=params, response_pagination=False)
+                                   data=data, response_pagination=False)
         return payload
 
     def __init__(self, **kwargs):
